@@ -9,6 +9,8 @@ from typing import TYPE_CHECKING, Annotated, Any, Literal
 
 from mkdocstrings import get_logger
 
+from mkdocstrings_handlers.python._internal.rendering import Order  # noqa: TC001
+
 # YORE: EOL 3.10: Replace block with line 2.
 if sys.version_info >= (3, 11):
     from typing import Self
@@ -184,6 +186,24 @@ class GoogleStyleOptions:
         ),
     ] = True
 
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for parameters, return values, etc.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
@@ -217,12 +237,57 @@ class NumpyStyleOptions:
         ),
     ] = True
 
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for parameters, return values, etc.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
 class SphinxStyleOptions:
     """Sphinx style docstring options."""
 
+    warn_unknown_params: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about documented parameters not appearing in the signature.",
+        ),
+    ] = True
+
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for return values.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
@@ -432,14 +497,24 @@ class PythonInputOptions:
     ] = field(default_factory=list)
 
     filters: Annotated[
-        list[str],
+        list[str] | Literal["public"],
         _Field(
             group="members",
-            description="""A list of filters applied to filter objects based on their name.
+            description="""A list of filters, or `"public"`.
+
+            **List of filters**
 
             A filter starting with `!` will exclude matching objects instead of including them.
             The `members` option takes precedence over `filters` (filters will still be applied recursively
             to lower members in the hierarchy).
+
+            **Filtering methods**
+
+            [:octicons-heart-fill-24:{ .pulse } Sponsors only](../insiders/index.md){ .insiders } &mdash;
+            [:octicons-tag-24: Insiders 1.11.0](../insiders/changelog.md#1.11.0)
+
+            The `public` method will include only public objects:
+            those added to `__all__` or not starting with an underscore (except for special methods/attributes).
             """,
         ),
     ] = field(default_factory=lambda: _DEFAULT_FILTERS.copy())
@@ -510,13 +585,18 @@ class PythonInputOptions:
     ] = None
 
     members_order: Annotated[
-        Literal["alphabetical", "source"],
+        Order | list[Order],
         _Field(
             group="members",
             description="""The members ordering to use.
 
-            - `alphabetical`: order by the members names,
+            - `__all__`: order members according to `__all__` module attributes, if declared;
+            - `alphabetical`: order members alphabetically;
             - `source`: order members as they appear in the source file.
+
+            Since `__all__` is a module-only attribute, it can't be used to sort class members,
+            therefore the `members_order` option accepts a list of ordering methods,
+            indicating ordering preferences.
             """,
         ),
     ] = "alphabetical"
@@ -537,6 +617,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    overloads_only: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Whether to hide the implementation signature if the overloads are shown.",
+        ),
+    ] = False
+
     parameter_headings: Annotated[
         bool,
         _Field(
@@ -597,6 +685,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    show_attribute_values: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Show initial values of attributes in classes.",
+        ),
+    ] = True
+
     show_bases: Annotated[
         bool,
         _Field(
@@ -832,6 +928,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    skip_local_inventory: Annotated[
+        bool,
+        _Field(
+            group="general",
+            description="Whether to prevent objects from being registered in the local objects inventory.",
+        ),
+    ] = False
+
     signature_crossrefs: Annotated[
         bool,
         _Field(
@@ -916,12 +1020,12 @@ class PythonInputOptions:
 class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
     """Final options passed as template context."""
 
-    filters: list[tuple[re.Pattern, bool]] = field(  # type: ignore[assignment]
+    filters: list[tuple[re.Pattern, bool]] | Literal["public"] = field(  # type: ignore[assignment]
         default_factory=lambda: [
             (re.compile(filtr.removeprefix("!")), filtr.startswith("!")) for filtr in _DEFAULT_FILTERS
         ],
     )
-    """A list of filters applied to filter objects based on their name."""
+    """A list of filters, or `"public"`."""
 
     summary: SummaryOption = field(default_factory=SummaryOption)
     """Whether to render summaries of modules, classes, functions (methods) and attributes."""
@@ -930,6 +1034,11 @@ class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
     def coerce(cls, **data: Any) -> MutableMapping[str, Any]:
         """Create an instance from a dictionary."""
         if "filters" in data:
+            # Non-insiders: transform back to default filters.
+            # Next: `if "filters" in data and not isinstance(data["filters"], str):`.
+            if data["filters"] == "public":
+                data["filters"] = _DEFAULT_FILTERS
+            # Filters are `None` or a sequence of strings (tests use tuples).
             data["filters"] = [
                 (re.compile(filtr.removeprefix("!")), filtr.startswith("!")) for filtr in data["filters"] or ()
             ]
@@ -949,7 +1058,7 @@ class Inventory:
         ),
     ]
 
-    base: Annotated[
+    base_url: Annotated[
         str | None,
         _Field(
             parent="inventories",
@@ -967,7 +1076,7 @@ class Inventory:
 
     @property
     def _config(self) -> dict[str, Any]:
-        return {"base": self.base, "domains": self.domains}
+        return {"base_url": self.base_url, "domains": self.domains}
 
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
@@ -997,7 +1106,9 @@ class PythonInputConfig:
 
     locale: Annotated[
         str | None,
-        _Field(description="The locale to use when translating template strings."),
+        _Field(
+            description="Deprecated. Use mkdocstrings' own `locale` setting instead. The locale to use when translating template strings.",
+        ),
     ] = None
 
     @classmethod
