@@ -190,7 +190,7 @@ def do_format_signature(
     # To fix this, we replace the CSS class in the first span with `nf`,
     # unless we already found an `nf` span.
     if not re.search(r'<span class="nf">', signature):
-        signature = re.sub(r'<span class="[a-z]+">', '<span class="nf">', signature, count=1)
+        signature = re.sub(r'<span class="[a-z]{1,2}">', '<span class="nf">', signature, count=1)
 
     if stash := env.filters["stash_crossref"].stash:
         for key, value in stash.items():
@@ -208,6 +208,7 @@ def do_format_attribute(
     line_length: int,
     *,
     crossrefs: bool = False,  # noqa: ARG001
+    show_value: bool = True,
 ) -> str:
     """Format an attribute.
 
@@ -235,7 +236,7 @@ def do_format_attribute(
             backlink_type="returned-by",
         )
         signature += f": {annotation}"
-    if attribute.value:
+    if show_value and attribute.value:
         value = template.render(context.parent, expression=attribute.value, signature=True, backlink_type="used-by")
         signature += f" = {value}"
 
@@ -261,7 +262,7 @@ def do_format_attribute(
 def do_order_members(
     members: Sequence[Object | Alias],
     order: Order | list[Order],
-    members_list: bool | list[str] | None,
+    members_list: bool | list[str] | None,  # noqa: FBT001
 ) -> Sequence[Object | Alias]:
     """Order members given an ordering method.
 
@@ -522,7 +523,7 @@ def _get_formatter() -> Callable[[str, int], str]:
 
 def _get_ruff_formatter() -> Callable[[str, int], str] | None:
     try:
-        from ruff.__main__ import find_ruff_bin
+        from ruff.__main__ import find_ruff_bin  # noqa: PLC0415
     except ImportError:
         return None
 
@@ -558,7 +559,7 @@ def _get_ruff_formatter() -> Callable[[str, int], str] | None:
 
 def _get_black_formatter() -> Callable[[str, int], str] | None:
     try:
-        from black import InvalidInput, Mode, format_str
+        from black import InvalidInput, Mode, format_str  # noqa: PLC0415
     except ModuleNotFoundError:
         return None
 
@@ -638,7 +639,7 @@ def do_as_attributes_section(
                 name=attribute.name,
                 description=_parse_docstring_summary(attribute),
                 annotation=attribute.annotation,
-                value=attribute.value,  # type: ignore[arg-type]
+                value=attribute.value,
             )
             for attribute in attributes
             if not check_public or attribute.is_public
